This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

PATCH: Add missing option to x86 as --help


I am checking in this patch to add missing options to x86 as --help.


H.J.
---
2007-12-29  H.J. Lu  <hongjiu.lu@intel.com>

	* config/tc-i386.c (md_show_usage): Add -mmnemonic, -msyntax,
	-mindex-reg, -mnaked-reg and -mold-gcc.

--- ./config/tc-i386.c.foo	2007-12-24 08:59:11.000000000 -0800
+++ ./config/tc-i386.c	2007-12-29 06:08:26.000000000 -0800
@@ -294,7 +294,7 @@ static int old_gcc = OLDGCC_COMPAT;
 /* 1 if register prefix % not required.  */
 static int allow_naked_reg = 0;
 
 /* 1 if fake index register, eiz/riz, is allowed .  */
 static int allow_index_reg = 0;
 
 /* Register prefix used for error message.  */
@@ -7177,7 +7177,16 @@ md_show_usage (stream)
   -march=CPU/-mtune=CPU   generate code/optimize for CPU, where CPU is one of:\n\
                            i386, i486, pentium, pentiumpro, pentium4, nocona,\n\
                            core, core2, k6, athlon, k8, generic32, generic64\n"));
-
+  fprintf (stream, _("\
+  -mmnemonic=[att|intel]  use AT&T/Intel mnemonic\n"));
+  fprintf (stream, _("\
+  -msyntax=[att|intel]    use AT&T/Intel syntax\n"));
+  fprintf (stream, _("\
+  -mindex-reg             support pseudo index registers\n"));
+  fprintf (stream, _("\
+  -mnaked-reg             don't require `%%' prefix for registers\n"));
+  fprintf (stream, _("\
+  -mold-gcc               support old (<= 2.8.1) versions of gcc\n"));
 }
 
 #if ((defined (OBJ_MAYBE_COFF) && defined (OBJ_MAYBE_AOUT)) \
@@ -294,7 +294,7 @@ static int old_gcc = OLDGCC_COMPAT;
 static int allow_naked_reg = 0;
 
-/* 1 if fake index register, eiz/riz, is allowed .  */
+/* 1 if pseudo index register, eiz/riz, is allowed .  */
 static int allow_index_reg = 0;
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]